@@ -2,7 +2,7 @@
 # pylint: disable-msg=W0231,R0904
 
 
-"""setuptools_support
+"""setuptools_support.
 
 License  : BSD (See COPYING)
 
@@ -86,7 +86,7 @@ def get_pkglist():
 
     dists = Distributions()
     projects = []
-    for (dist, _active) in dists.get_distributions('all'):
+    for (dist, _) in dists.get_distributions('all'):
         if dist.project_name not in projects:
             projects.append(dist.project_name)
     return projects
